<?php
/**
 * Custom theme functions.
 *
 * This file contains hook functions attached to theme hooks.
 *
 * @package Hedwix_Outreach
 */

if ( ! function_exists( 'hedwix_outreach_skip_to_content' ) ) :

	/**
	 * Add Skip to content.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_skip_to_content() {
	?><a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'hedwix-outreach' ); ?></a><?php
	}

endif;

add_action( 'hedwix_outreach_action_before', 'hedwix_outreach_skip_to_content', 15 );

if ( ! function_exists( 'hedwix_outreach_site_branding' ) ) :

	/**
	 * Site branding.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_site_branding() {

	?>
	
    <div class="site-branding">
		<?php hedwix_outreach_the_custom_logo(); ?>
		<?php $show_title = hedwix_outreach_get_option( 'show_title' ); ?>
		<?php $show_tagline = hedwix_outreach_get_option( 'show_tagline' ); ?>
		<?php if ( true === $show_title || true === $show_tagline ) : ?>
			<div id="site-header">
				<?php if ( true === $show_title ) :  ?>
					<?php if ( is_front_page() && is_home() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="navbar-brand" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="navbar-brand" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php endif; ?>
				<?php endif; ?>

				<?php if ( true === $show_tagline ) : ?>
					<p class="site-description"><?php bloginfo( 'description' ); ?></p>
				<?php endif; ?>
			</div><!-- #site-identity -->
		<?php endif; ?>
    </div><!-- .site-branding -->

    <?php

	}

endif;

add_action( 'hedwix_outreach_action_header', 'hedwix_outreach_site_branding' );


if ( ! function_exists( 'hedwix_outreach_add_primary_navigation' ) ) :

	/**
	 * Site branding.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_add_primary_navigation() {
	?>
    <nav id="site-navigation" class="main-navigation" role="navigation">
    	<button type="button" class="menu-toggle">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
        </button>
        
		<?php
		wp_nav_menu( array(
			'theme_location' => 'primary',
			'menu_id'        => 'primary-menu',
			'menu_class'     => 'nav-menu',
			'fallback_cb'    => 'hedwix_outreach_primary_navigation_fallback',
		) );
		?>
    </nav><!-- #site-navigation -->
    <?php
	}

endif;
add_action( 'hedwix_outreach_action_header', 'hedwix_outreach_add_primary_navigation', 20 );




if ( ! function_exists( 'hedwix_outreach_footer_copyright' ) ) :

	/**
	 * Footer copyright
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_footer_copyright() {

		// Check if footer is disabled.
		$footer_status = apply_filters( 'hedwix_outreach_filter_footer_status', true );
		if ( true !== $footer_status ) {
			return;
		}

		// Copyright content.
		$copyright_text = hedwix_outreach_get_option( 'copyright_text' );
		$copyright_text = apply_filters( 'hedwix_outreach_filter_copyright_text', $copyright_text );
		if ( ! empty( $copyright_text ) ) {
			$copyright_text = wp_kses_data( $copyright_text );
		}

	?>

    <?php if ( ! empty( $footer_menu_content ) ) :  ?>
		<?php echo wp_kses_post( $footer_menu_content ); ?>
    <?php endif ?>

    	
    <div class="site-info">
    	<div class="container">
			<p><?php echo wp_kses_data( $copyright_text ); ?><?php printf( esc_html__( ' | Theme: %1$s by %2$s.', 'hedwix-outreach' ), 'Hedwix Outreach', '<a href="'.esc_url( __( 'www.hedwix.com', 'hedwix-outreach' ) ).'" rel="designer">Hedwix</a>' ); ?></a></p>
    	</div><!-- .container -->
    </div><!-- .site-info -->
        
    <?php
	}

endif;

add_action( 'hedwix_outreach_action_footer', 'hedwix_outreach_footer_copyright', 10 );


if ( ! function_exists( 'hedwix_outreach_add_sidebar' ) ) :

	/**
	 * Add sidebar.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_add_sidebar() {

		global $post;

		$page_layout = hedwix_outreach_get_option( 'page_layout' );
		$page_layout = apply_filters( 'hedwix_outreach_filter_theme_page_layout', $page_layout );

		// Check if single.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'hedwix_outreach_theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$page_layout = $post_options['post_layout'];
			}
		}

		// Include primary sidebar.
		if ( 'no-sidebar' !== $page_layout ) {
			get_sidebar();
		}
	}

endif;

add_action( 'hedwix_outreach_action_sidebar', 'hedwix_outreach_add_sidebar' );


if ( ! function_exists( 'hedwix_outreach_custom_posts_navigation' ) ) :
	/**
	 * Posts navigation.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_custom_posts_navigation() {

		$pagination_type = hedwix_outreach_get_option( 'pagination_type' );

		switch ( $pagination_type ) {

			case 'default':
				the_posts_navigation();
			break;

			case 'numeric':
				the_posts_pagination();
			break;

			default:
			break;
		}

	}
endif;

add_action( 'hedwix_outreach_action_posts_navigation', 'hedwix_outreach_custom_posts_navigation' );


if ( ! function_exists( 'hedwix_outreach_add_image_in_single_display' ) ) :

	/**
	 * Add image in single post.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_add_image_in_single_display() {

		global $post;

		// Bail if current post is built with Page Builder.
        if ( true === hedwix_outreach_content_is_pagebuilder() ) {
			return;
        }
		// Bail if checkbox Use Featured Image as Banner is enabled.
		$values = get_post_meta( $post->ID, 'hedwix_outreach_theme_settings', true );
        if ( isset( $values['use_featured_image_as_banner'] ) && 1 === absint( $values['use_featured_image_as_banner'] ) ) {
			return;
        }
		if ( has_post_thumbnail() ) {

			$values = get_post_meta( $post->ID, 'hedwix_outreach_theme_settings', true );
			$single_image = isset( $values['single_image'] ) ? esc_attr( $values['single_image'] ) : '';

			if ( ! $single_image ) {
				$single_image = hedwix_outreach_get_option( 'single_image' );
			}

			if ( 'disable' !== $single_image ) {
				$args = array(
					'class' => 'aligncenter',
				);
				the_post_thumbnail( esc_attr( $single_image ), $args );
			}
		}

	}

endif;

add_action( 'hedwix_outreach_single_image', 'hedwix_outreach_add_image_in_single_display' );

if ( ! function_exists( 'hedwix_outreach_add_author_bio_in_single' ) ) :

	/**
	 * Display Author bio.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_add_author_bio_in_single() {

		if ( is_singular( 'post' ) ) {
			global $post;
			if ( get_the_author_meta( 'description', $post->post_author ) ) {
				get_template_part( 'template-parts/author-bio', 'single' );
			}
		}

	}

endif;

add_action( 'hedwix_outreach_author_bio', 'hedwix_outreach_add_author_bio_in_single' );

if ( ! function_exists( 'hedwix_outreach_primary_navigation_fallback' ) ) :

	/**
	 * Fallback for primary navigation.
	 *
	 * @since 1.0
	 */
	function hedwix_outreach_primary_navigation_fallback() {
		echo '<ul>';
		echo '<li><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'hedwix-outreach' ). '</a></li>';
		wp_list_pages( array(
			'title_li' => '',
			'depth'    => 1,
			'number'   => 7,
		) );
		echo '</ul>';

	}

endif;
